This is a pcap capture handle which is an abstraction over the pcap_t provided by pcap.
There are many ways to instantiate and interact with a pcap handle, so phantom types are
used to express these behaviors.
Phantom type representing a dead capture handle. This can be use to create
new save files that are not generated from an active capture.
Implements Activated because it behaves nearly the same as a live handle.