Crate async_pcap

Crate async_pcap 

Structs

AsyncCapture
An asynchronous wrapper around a pcap::Capture.
AsyncCaptureHandle
Handle to control the asynchronous capture.
Capture
This is a pcap capture handle which is an abstraction over the pcap_t provided by pcap. There are many ways to instantiate and interact with a pcap handle, so phantom types are used to express these behaviors.
Device
A network device name and pcap’s description of it.
Packet
Represents a network packet with its header and raw data.

Enums

Active
Phantom type representing an active capture handle.